@@ -5,9 +5,11 @@ import itertools
 from .exceptions import *
 from .imputil import ClassFinder
 
-__all__ = [
-    "ModuleList", "KeyConstraintDict", "PrefixedKeyDict",
-]
+def chain(fun):
+    def chained(self, *args, **kwargs):
+        fun(self, *args, **kwargs)
+        return self
+    return chained
 
 def lchop(string, prefix):
     if string.startswith(prefix):
@@ -50,6 +52,7 @@ class ModuleList(collections.UserList):
         module = self.finder.instanciate_class_from_module(module, *args, **kwargs)
         module.registered(self.status_handler)
         super().append(module)
+        return module
 
     def get_by_id(self, find_id):
         find_id = int(find_id)
@@ -98,3 +101,8 @@ class KeyConstraintDict(collections.UserDict):
 
     def missing(self):
         return self.required_keys - (self.seen_keys & self.required_keys)
+
+def convert_position(pos, json):
+    if pos < 0:
+        pos = len(json) + (pos+1)
+    return pos
